| CrossValidation | R Documentation |
Class of object returned by the QuadrupenFit$cross_validate() method or the
cross_validate() function. Owns print() and plot() methods.
dataa data frame containing the mean
cross-validated error and its associated standard error for each
values of lambda1 and lambda2.
foldslist of K vectors indicating the folds
used for cross-validation.
lambda1vector of \lambda_1
(\ell_1 or \ell_\infty penalty levels)
for which each cross-validation has been performed.
lambda2vector (or scalar) of \ell_2-penalty levels for
which each cross-validation has been performed.
lambda1_minlevel of \lambda_1 that minimizes the
error estimated by cross-validation.
lambda2_minlevel of \lambda_2 that minimizes the
error estimated by cross-validation.
lambda1_1selargest level of \lambda_1 such as
the cross-validated error is within 1 standard error of the
minimum.
lambda2_1selargest level of \lambda_2
such that the cross-validated error is within 1 standard error of the
minimum (only relevant for ridge regression).
CrossValidation$new()Constructor for a CrossValidation object
Should be called internally by an object QuadrupenFit$cross_validate()
CrossValidation$new(cv_error, folds)
cv_errordata frame storing output of a cv job
foldslist of K folds used for cross-validation
CrossValidation$show()User friendly print method
CrossValidation$show()
CrossValidation$print()User friendly print method
CrossValidation$print()
CrossValidation$plotCV_1D()Plot 1-dimensional cross-validation
CrossValidation$plotCV_1D( log_scale = TRUE, title = "Cross-validation error", se = TRUE )
log_scalelogical, should a log-scale be used for the x-axis
titlegraph title
selogical, should confidence band be displayed (TRUE by default)
a ggplot object
CrossValidation$plotCV_2D()Plot 2-dimensional cross-validation output (grid lambda1 x lambda2)
CrossValidation$plotCV_2D(title = "Cross-validation error")
titlegraph title
a ggplot2 object
CrossValidation$plot()Plot cross-validation job by choosing the most appropriate output (1D- or 2D)
CrossValidation$plot(log_scale = TRUE, title = "Cross-validation error")
log_scalelogical, should a log-scale be used for the x-axis
titlegraph title
a ggplot object
CrossValidation$clone()The objects of this class are cloneable with this method.
CrossValidation$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.