Skip to contents

Class "ElasticNetFit"

Class "ElasticNetFit"

Details

Class of object returned by the fitting function elastic.net(). Inherits fields and methods of QuadrupenFit

Super class

quadrupen::QuadrupenFit -> ElasticNetFit

Active bindings

penalty

character describing the regularizer/penalty

Methods

Inherited methods


Method new()

Initialize a ElasticNetFit model

Usage

ElasticNetFit$new(data, intercept, regParam)

Arguments

data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

regParam

a list with two elements, a vector and a scalar, for the regularization


Method clone()

The objects of this class are cloneable with this method.

Usage

ElasticNetFit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.