Skip to contents

Class "GroupLassoFit"

Class "GroupLassoFit"

Details

Class of object returned by the fitting function group.lasso(). Inherits fields and methods of QuadrupenFit

Super class

quadrupen::QuadrupenFit -> GroupLassoFit

Active bindings

penalty

character describing the regularizer/penalty

group

vector of integers indicating group belonging

type

string indicating whether the \(\ell_1/\ell_2\) or the \(\ell_1/\ell_\infty\) group-Lasso must be fitted.

Methods

Inherited methods


Method new()

Initialize a GroupLassoFit model

Usage

GroupLassoFit$new(data, intercept, group, type, regParam)

Arguments

data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

group

vector of integers indicating group belonging.

type

string indicating whether the \(\ell_1/\ell_2\) or the \(\ell_1/\ell_\infty\) group-Lasso must be fitted.

regParam

a list with two elements, a vector and a scalar, for the regularization


Method clone()

The objects of this class are cloneable with this method.

Usage

GroupLassoFit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.