GroupLavaFit: Class "GroupLavaFit"

GroupLavaFitR Documentation

Class "GroupLavaFit"

Description

Class of object returned by the fitting function group_lava(). Inherits fields and methods of QuadrupenFit and LavaFit

Super classes

QuadrupenFit -> LavaFit -> GroupLavaFit

Active bindings

lambda1

vector of tuning parameters for the l1 group penalty (sparse component)

lambda2

vector of tuning parameters for the l2 penalty (dense component)

penalty

character describing the regularizer/penalty

group

vector of integers indicating group belonging

type

string indicating whether the \ell_1/\ell_2 or the \ell_1/\ell_\infty group-Lasso must be fitted.

Methods

Public methods

Inherited methods

GroupLavaFit$new()

Initialize a GroupLavaFit model

Usage
GroupLavaFit$new(data, intercept, group, type, regParam)
Arguments
data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

group

vector of integers indicating group belonging.

type

string indicating whether the \ell_1/\ell_2 or the \ell_1/\ell_\infty group-Lasso must be fitted.

regParam

a list with two elements, a vector and a scalar, for the regularization


GroupLavaFit$clone()

The objects of this class are cloneable with this method.

Usage
GroupLavaFit$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

QuadrupenFit, group_lava()


quadrupen documentation built on Sept. 18, 2026, 1:06 a.m.