RidgeRegressionFit: Class "RidgeRegressionFit"

RidgeRegressionFitR Documentation

Class "RidgeRegressionFit"

Description

Class of object returned by the fitting function ridge(). Inherits fields and methods of QuadrupenFit.

Super class

QuadrupenFit -> RidgeRegressionFit

Active bindings

penalty

character describing the regularizer/penalty

lambda2

vector of tuning parameters for the l2 penalty

Methods

Public methods

Inherited methods

RidgeRegressionFit$new()

Initialize a RidgeRegressionFit model

Usage
RidgeRegressionFit$new(data, intercept, regParam)
Arguments
data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

regParam

a list with two elements, a vector and a scalar, for the regularization


RidgeRegressionFit$clone()

The objects of this class are cloneable with this method.

Usage
RidgeRegressionFit$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

QuadrupenFit, ridge()


quadrupen documentation built on Sept. 18, 2026, 1:06 a.m.