| SparseFit | R Documentation |
Class of object returned by the fitting function elastic_net(). Inherits fields
and methods of QuadrupenFit
QuadrupenFit -> SparseFit
lambda1vector of tuning parameters for the l1 penalty
lambda2vector of tuning parameters for the l2 penalty
penaltycharacter describing the regularizer/penalty
typestring the type of group-wise regularization applied
unbiasing_tuningunbiasing coefficient of the MCP or SCAD penalties
SparseFit$new()Initialize a SparseFit model
SparseFit$new(data, intercept, type, regParam)
dataa DataModel object
intercepta logical; should an intercept be included in the mode?
typestring the type of group-wise regularization applied
regParama list with two elements, a vector and a scalar, for the regularization
SparseFit$clone()The objects of this class are cloneable with this method.
SparseFit$clone(deep = FALSE)
deepWhether to make a deep clone.
QuadrupenFit, elastic_net()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.