SparseGroupFit: Class "SparseGroupFit"

SparseGroupFitR Documentation

Class "SparseGroupFit"

Description

Class of object returned by the fitting function group_sparse_lm(). Inherits fields and methods of QuadrupenFit

Super class

QuadrupenFit -> SparseGroupFit

Active bindings

lambda1

vector of tuning parameters for the l1 group penalty

lambda2

vector of tuning parameters for the l2 penalty

alpha

mixing parameter of the sparse group-penalty

penalty

character describing the regularizer/penalty

group

vector of integers indicating group belonging

type

string the type of group-wise regularization applied

mixture_tuning

mixture coefficient of the sparse group penalty

is_group_sparse

boolean indicating if sparse group or group penalty is applied

Methods

Public methods

Inherited methods

SparseGroupFit$new()

Initialize a SparseGroupFit model

Usage
SparseGroupFit$new(data, intercept, group, type, regParam)
Arguments
data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

group

vector of integers indicating group belonging.

type

string indicating whether the \ell_1/\ell_2 or the \ell_1/\ell_\infty group-Lasso must be fitted.

regParam

a list with two elements, a vector and a scalar, for the regularization


SparseGroupFit$clone()

The objects of this class are cloneable with this method.

Usage
SparseGroupFit$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

QuadrupenFit, group_sparse_lm()


quadrupen documentation built on Sept. 18, 2026, 1:06 a.m.