Class of object returned by a cross-validation performed through
the crossval method.
lambda1:vector of \(\lambda_1\) (\(\ell_1\) or \(\ell_\infty\) penalty levels) for which each cross-validation has been performed.
lambda2:vector (or scalar) of \(\ell_2\)-penalty levels for which each cross-validation has been performed.
lambda1.min:level of \(\lambda_1\) that minimizes the error estimated by cross-validation.
lambda1.1se:largest level of \(\lambda_1\) such as the cross-validated error is within 1 standard error of the minimum.
lambda2.min:level of \(\lambda_2\) that minimizes the error estimated by cross-validation.
cv.error:a data frame containing the mean
cross-validated error and its associated standard error for each
values of lambda1 and lambda2.
folds:list of K vectors indicating the folds
used for cross-validation.
beta.min:the vector of parameters obtained by
fitting the problem on the full data set x and y with
lambda1.min and lambda2.min penalties.
beta.1se:the vector of parameters obtained by
fitting the problem on the full data set x and y with
lambda1.1se and lambda2.min penalties.
The specific plot,cvpen-method method is documented.
See also plot,cvpen-method and
crossval.