isQuadrupenFit: Auxiliary functions to check the given class of an object

View source: R/quadrupen-S3Methods.R

isQuadrupenFitR Documentation

Auxiliary functions to check the given class of an object

Description

Auxiliary functions to check the given class of an object

Usage

isQuadrupenFit(Robject)

Arguments

Robject

an R object to evaluate

Value

logical


quadrupen documentation built on Sept. 18, 2026, 1:06 a.m.