Learn R Programming

quadrupen (version 0.2-4)

quadrupen-class: Class "quadrupen"

Description

Class of object returned by any fitting function of the quadrupen package (elastic.net or bounded.reg).

Arguments

Slots

coefficients:
Matrix (class "dgCMatrix") of coefficients with respect to the original input. The number of rows corresponds the length of lambda1.
active.set:
Matrix (class "dgCMatrix", generally sparse) indicating the 'active' variables, in the sense that they activate the constraints. For the elastic.net, it corresponds to the nonzero variables; for the bounded.reg function, it is the set of variables reaching the boudary along the path of solutions.
intercept:
logical; indicates if an intercept has been included to the model.
mu:
A vector (class "numeric") containing the successive values of the (unpenalized) intercept. Equals to zero if intercept has been set to FALSE.
meanx:
Vector (class "numeric") containing the column means of the predictor matrix.
normx:
Vector (class "numeric") containing the square root of the sum of squares of each column of the design matrix.
penscale:
Vector "numeric" with real positive values that have been used to weight the penalty tuned by $lambda1$.
penalty:
Object of class "character" indicating the method used ("elastic-net" or "bounded regression").
naive:
logical; was the naive mode on?
lambda1:
Vector (class "numeric") of penalty levels (either $l1$ or $l-infinity$) for which the model has eventually been fitted.
lambda2:
Scalar (class "numeric") for the amount of $l2$ (ridge-like) penalty.
struct:
Object of class "Matrix" used to structure the coefficients in the $l2$ penalty.
control:
Object of class "list" with low level options used for optimization.
monitoring:
List (class "list") which contains various indicators dealing with the optimization process.
residuals:
Matrix of residuals, each column corresponding to a value of lambda1.
r.squared:
Vector (class "numeric") given the coefficient of determination as a function of lambda1.
fitted:
Matrix of fitted values, each column corresponding to a value of lambda1.

Methods

This class comes with the usual predict(object, newx, ...), fitted(object, ...), residuals(object, ...), print(object, ...), show(object) and deviance(object, ...) generic (undocumented) methods. A specific plotting method is available and documented (plot,quadrupen-method).

See Also

See also plot,quadrupen-method.