Skip to contents

Class of object returned by the fitting function bounded_reg(). Inherits fields and methods of QuadrupenFit.

Super class

QuadrupenFit -> BoundedRegressionFit

Active bindings

penalty

character describing the regularizer/penalty

lambdainf

vector of tuning parameters for the linf penalty

lambda2

vector of tuning parameters for the l2 penalty

Methods

Inherited methods


BoundedRegressionFit$new()

Initialize a BoundedRegressionFit model

Usage

BoundedRegressionFit$new(data, intercept, regParam)

Arguments

data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

regParam

a list with two elements, a vector and a scalar, for the regularization


BoundedRegressionFit$clone()

The objects of this class are cloneable with this method.

Usage

BoundedRegressionFit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.