Class of object returned by the fitting function bounded_reg(). Inherits fields
and methods of QuadrupenFit.
Super class
QuadrupenFit -> BoundedRegressionFit
Active bindings
penaltycharacter describing the regularizer/penalty
lambdainfvector of tuning parameters for the linf penalty
lambda2vector of tuning parameters for the l2 penalty
Methods
BoundedRegressionFit$new()
Initialize a BoundedRegressionFit model
Usage
BoundedRegressionFit$new(data, intercept, regParam)Arguments
dataa
DataModelobjectintercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization