| BoundedRegressionFit | R Documentation |
Class of object returned by the fitting function bounded_reg(). Inherits fields
and methods of QuadrupenFit.
QuadrupenFit -> BoundedRegressionFit
penaltycharacter describing the regularizer/penalty
lambdainfvector of tuning parameters for the linf penalty
lambda2vector of tuning parameters for the l2 penalty
BoundedRegressionFit$new()Initialize a BoundedRegressionFit model
BoundedRegressionFit$new(data, intercept, regParam)
dataa DataModel object
intercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization
BoundedRegressionFit$clone()The objects of this class are cloneable with this method.
BoundedRegressionFit$clone(deep = FALSE)
deepWhether to make a deep clone.
QuadrupenFit, bounded_reg()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.