Class CrossValidation
Class CrossValidation
Details
Class of object returned by the QuadrupenFit$cross_validate() method or the
cross_validate() function. Owns print() and plot() methods.
Active bindings
dataa data frame containing the mean cross-validated error and its associated standard error for each values of
lambda1andlambda2.foldslist of
Kvectors indicating the folds used for cross-validation.lambda1vector of \(\lambda_1\) (\(\ell_1\) or \(\ell_\infty\) penalty levels) for which each cross-validation has been performed.
lambda2vector (or scalar) of \(\ell_2\)-penalty levels for which each cross-validation has been performed.
lambda1_minlevel of \(\lambda_1\) that minimizes the error estimated by cross-validation.
lambda2_minlevel of \(\lambda_2\) that minimizes the error estimated by cross-validation.
lambda1_1selargest level of \(\lambda_1\) such as the cross-validated error is within 1 standard error of the minimum.
lambda2_1selargest level of \(\lambda_2\) the cross-validated error is within 1 standard error of the minimum (only relevant for ridge regression).
Methods
Method new()
Constructor for a CrossValidation object
Should be called internally by an object QuadrupenFit$cross_validate()
Usage
CrossValidation$new(cv_error, folds)Method plot()
Plot cross-validation job by choosing the most appropriate output (1D- or 2D)