Skip to contents

Class of object returned by the fitting function fused_lasso(). Inherits fields and methods of QuadrupenFit.

Super class

QuadrupenFit -> FusedLassoFit

Active bindings

penalty

character describing the regularizer/penalty

lambda1

vector of tuning parameters for the l1 penalty

lambda2

vector of tuning parameters for the fusion penalty

Methods

Inherited methods


FusedLassoFit$new()

Initialize a FusedLassoFit model

Usage

FusedLassoFit$new(data, intercept, regParam)

Arguments

data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

regParam

a list with two elements, a vector and a scalar, for the regularization


FusedLassoFit$clone()

The objects of this class are cloneable with this method.

Usage

FusedLassoFit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.