Class of object returned by the fitting function fused_lasso(). Inherits fields
and methods of QuadrupenFit.
Super class
QuadrupenFit -> FusedLassoFit
Active bindings
penaltycharacter describing the regularizer/penalty
lambda1vector of tuning parameters for the l1 penalty
lambda2vector of tuning parameters for the fusion penalty
Methods
FusedLassoFit$new()
Initialize a FusedLassoFit model
Usage
FusedLassoFit$new(data, intercept, regParam)Arguments
dataa
DataModelobjectintercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization