Skip to contents

Class "FusedLassoFit"

Class "FusedLassoFit"

Details

Class of object returned by the fitting function fusedlasso(). Inherits fields and methods of QuadrupenFit.

Super class

quadrupen::QuadrupenFit -> FusedLassoFit

Active bindings

penalty

character describing the regularizer/penalty

Methods

Inherited methods


Method new()

Initialize a FusedLassoFit model

Usage

FusedLassoFit$new(data, intercept, regParam)

Arguments

data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

regParam

a list with two elements, a vector and a scalar, for the regularization


Method clone()

The objects of this class are cloneable with this method.

Usage

FusedLassoFit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.