| FusedLassoFit | R Documentation |
Class of object returned by the fitting function fused_lasso(). Inherits fields
and methods of QuadrupenFit.
QuadrupenFit -> FusedLassoFit
penaltycharacter describing the regularizer/penalty
lambda1vector of tuning parameters for the l1 penalty
lambda2vector of tuning parameters for the fusion penalty
FusedLassoFit$new()Initialize a FusedLassoFit model
FusedLassoFit$new(data, intercept, regParam)
dataa DataModel object
intercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization
FusedLassoFit$clone()The objects of this class are cloneable with this method.
FusedLassoFit$clone(deep = FALSE)
deepWhether to make a deep clone.
QuadrupenFit, bounded_reg()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.