Class of object returned by the fitting function group_lava(). Inherits fields
and methods of QuadrupenFit and LavaFit
Super classes
QuadrupenFit -> LavaFit -> GroupLavaFit
Active bindings
lambda1vector of tuning parameters for the l1 group penalty (sparse component)
lambda2vector of tuning parameters for the l2 penalty (dense component)
penaltycharacter describing the regularizer/penalty
groupvector of integers indicating group belonging
typestring indicating whether the \(\ell_1/\ell_2\) or the \(\ell_1/\ell_\infty\) group-Lasso must be fitted.
Methods
GroupLavaFit$new()
Initialize a GroupLavaFit model
Usage
GroupLavaFit$new(data, intercept, group, type, regParam)Arguments
dataa
DataModelobjectintercepta logical; should an intercept be included in the mode?
groupvector of integers indicating group belonging.
typestring indicating whether the \(\ell_1/\ell_2\) or the \(\ell_1/\ell_\infty\) group-Lasso must be fitted.
regParama list with two elements, a vector and a scalar, for the regularization