| GroupLavaFit | R Documentation |
Class of object returned by the fitting function group_lava(). Inherits fields
and methods of QuadrupenFit and LavaFit
QuadrupenFit -> LavaFit -> GroupLavaFit
lambda1vector of tuning parameters for the l1 group penalty (sparse component)
lambda2vector of tuning parameters for the l2 penalty (dense component)
penaltycharacter describing the regularizer/penalty
groupvector of integers indicating group belonging
typestring indicating whether the \ell_1/\ell_2 or the
\ell_1/\ell_\infty group-Lasso must be fitted.
GroupLavaFit$new()Initialize a GroupLavaFit model
GroupLavaFit$new(data, intercept, group, type, regParam)
dataa DataModel object
intercepta logical; should an intercept be included in the mode?
groupvector of integers indicating group belonging.
typestring indicating whether the \ell_1/\ell_2 or the
\ell_1/\ell_\infty group-Lasso must be fitted.
regParama list with two elements, a vector and a scalar, for the regularization
GroupLavaFit$clone()The objects of this class are cloneable with this method.
GroupLavaFit$clone(deep = FALSE)
deepWhether to make a deep clone.
QuadrupenFit, group_lava()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.