Class InformationCriteria
Class InformationCriteria
Details
Class of object returned by the QuadrupenFit$criteria() method or the
criteria() function. Owns print() and plot() methods.
Active bindings
dataa data frame containing the values of various information criteria (AIC, BIC, lmBIC, eBIC, GCV) along the value of
lambda1.lambdavector of \(\lambda_1\) (\(\ell_1\) or \(\ell_\infty\) penalty levels) for which each cross-validation has been performed.
namesa vector of characters storing the names of the precomputed criteria
Methods
Method new()
Constructor for a InformationCriteria object
Should be called internally by an object QuadrupenFit$criteria()
Usage
InformationCriteria$new(value)Arguments
valuedata frame storing output of
QuadrupenFit$criteria()
Method plot()
Plot the the desired criteria
Usage
InformationCriteria$plot(
criteria = self$names,
log_scale = TRUE,
xvar = c("lambda", "fraction", "df"),
title = "Information Criteria"
)Arguments
criteriaa vector of character with the criteria to plot. The default plot all the criteria available (stored in the field
names)log_scalelogical; indicates if a log-scale should be used when
xvar="lambda". Default isTRUE.xvarvariable to plot on the X-axis: either
"df"(the estimated degrees of freedom),"lambda"(\(\lambda_1\) penalty level) or"fraction"(\(\ell_1\)-norm of the coefficients). Default is set to"lambda".titlegraph title