| InformationCriteria | R Documentation |
Class of object returned by the QuadrupenFit$criteria() method or the
criteria() function. Owns print() and plot() methods.
dataa data frame containing the values of various information
criteria (AIC, BIC, lmBIC, eBIC, GCV) along the value of lambda1.
lambdavector of \lambda_1
(\ell_1 or \ell_\infty penalty levels)
for which each cross-validation has been performed.
namesa vector of characters storing the names of the precomputed criteria
InformationCriteria$new()Constructor for a InformationCriteria object
Should be called internally by an object QuadrupenFit$criteria()
InformationCriteria$new(value)
valuedata frame storing output of QuadrupenFit$criteria()
InformationCriteria$show()User friendly print method
InformationCriteria$show()
InformationCriteria$print()User friendly print method
InformationCriteria$print()
InformationCriteria$plot()Plot the the desired criteria
InformationCriteria$plot(
criteria = self$names,
log_scale = TRUE,
xvar = c("lambda", "fraction", "df"),
title = "Information Criteria"
)
criteriaa vector of character with the criteria to plot.
The default plot all the criteria available (stored in the field names)
log_scalelogical; indicates if a log-scale should be used
when xvar="lambda". Default is TRUE.
xvarvariable to plot on the X-axis: either "df"
(the estimated degrees of freedom), "lambda"
(\lambda_1 penalty level) or "fraction"
(\ell_1-norm of the coefficients). Default is set to
"lambda".
titlegraph title
a ggplot2 object
InformationCriteria$clone()The objects of this class are cloneable with this method.
InformationCriteria$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.