Class "LavaFit"
Class "LavaFit"
Details
Class of object returned by the fitting function lava(). Inherits fields
and methods of QuadrupenFit
Super class
quadrupen::QuadrupenFit -> LavaFit
Active bindings
penaltycharacter describing the regularizer/penalty
sparse_coefsparse part of the decomposition of the coefficients
dense_coefdense part of the decomposition of the coefficients
debiaslogical, should we rely on the debias coefficient of the regularizer (if available) or not
Methods
Method new()
Initialize a LavaFit model
Usage
LavaFit$new(data, intercept, regParam)Arguments
dataa
DataModelobjectintercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization
Method plot_path()
Produce a plot of the solution path of a LavaFit object.
Arguments
xvarvariable to plot on the X-axis: either
"lambda"(\(\ell_1\) penalty level, or \(\ell_2\) for ridge and \(\ell_\infty\)) or"fraction"(\(\ell_1\)-norm of the coefficients) ordffor estimated degrees of freedom. Default is set to"lambda".log_scalelogical; indicates if a log-scale should be used when
xvar="lambda". Default isTRUE.componenta character indicating the component to plot: both (sum of sparse and dense), sparse or dense. Default to both.
titlethe title. Default is set to the model name followed by what is on the Y-axis.
standardizelogical; standardize the coefficients before plotting (with the norm of the predictor). Default is
TRUE.labelsvector indicating the names associated to the plotted variables. When specified, a legend is drawn in order to identify each variable. Only relevant when the number of predictor is small. Remind that the intercept does not count. Default is
NULL.