| LavaFit | R Documentation |
Class of object returned by the fitting function lava(). Inherits fields
and methods of QuadrupenFit
QuadrupenFit -> LavaFit
penaltycharacter describing the regularizer/penalty
lambda1vector of tuning parameters for the l1 penalty (sparse component)
lambda2vector of tuning parameters for the l2 penalty (dense component)
sparse_coefsparse part of the decomposition of the coefficients
dense_coefdense part of the decomposition of the coefficients
debiaslogical, should we rely on the debias coefficient of the regularizer (if available) or not
LavaFit$new()Initialize a LavaFit model
LavaFit$new(data, intercept, regParam)
dataa DataModel object
intercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization
LavaFit$fit()function performing the optimization
LavaFit$fit(control)
controllist controlling the optimization process Plot method for lava regularization path
LavaFit$plot_path()Produce a plot of the solution path of a LavaFit object.
LavaFit$plot_path(
xvar = c("lambda", "fraction", "df"),
log_scale = TRUE,
component = "both",
title = paste("Lava path:", component, "component(s)"),
standardize = TRUE,
labels = NULL
)
xvarvariable to plot on the X-axis: either "lambda"
(\ell_1 penalty level, or
\ell_2 for ridge and \ell_\infty) or
"fraction" (\ell_1-norm
of the coefficients) or df for estimated degrees of freedom.
Default is set to "lambda".
log_scalelogical; indicates if a log-scale should be used
when xvar="lambda". Default is TRUE.
componenta character indicating the component to plot: both (sum of sparse and dense), sparse or dense. Default to both.
titlethe title. Default is set to the model name followed by what is on the Y-axis.
standardizelogical; standardize the coefficients before
plotting (with the norm of the predictor). Default is TRUE.
labelsvector indicating the names associated to the plotted
variables. When specified, a legend is drawn in order to identify
each variable. Only relevant when the number of predictor is
small. Remind that the intercept does not count. Default is
NULL.
a ggplot2 object .
LavaFit$clone()The objects of this class are cloneable with this method.
LavaFit$clone(deep = FALSE)
deepWhether to make a deep clone.
QuadrupenFit, lava()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.