Class of object returned by the fitting function ridge(). Inherits fields
and methods of QuadrupenFit.
Super class
QuadrupenFit -> RidgeRegressionFit
Active bindings
penaltycharacter describing the regularizer/penalty
lambda2vector of tuning parameters for the l2 penalty
Methods
RidgeRegressionFit$new()
Initialize a RidgeRegressionFit model
Usage
RidgeRegressionFit$new(data, intercept, regParam)Arguments
dataa
DataModelobjectintercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization