Skip to contents

Class "RidgeRegressionFit"

Class "RidgeRegressionFit"

Details

Class of object returned by the fitting function ridge(). Inherits fields and methods of QuadrupenFit.

See also

Super class

quadrupen::QuadrupenFit -> RidgeRegressionFit

Active bindings

penalty

character describing the regularizer/penalty

Methods

Inherited methods


Method new()

Initialize a RidgeRegressionFit model

Usage

RidgeRegressionFit$new(data, intercept, regParam)

Arguments

data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

regParam

a list with two elements, a vector and a scalar, for the regularization


Method clone()

The objects of this class are cloneable with this method.

Usage

RidgeRegressionFit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.