| RidgeRegressionFit | R Documentation |
Class of object returned by the fitting function ridge(). Inherits fields
and methods of QuadrupenFit.
QuadrupenFit -> RidgeRegressionFit
penaltycharacter describing the regularizer/penalty
lambda2vector of tuning parameters for the l2 penalty
RidgeRegressionFit$new()Initialize a RidgeRegressionFit model
RidgeRegressionFit$new(data, intercept, regParam)
dataa DataModel object
intercepta logical; should an intercept be included in the mode?
regParama list with two elements, a vector and a scalar, for the regularization
RidgeRegressionFit$clone()The objects of this class are cloneable with this method.
RidgeRegressionFit$clone(deep = FALSE)
deepWhether to make a deep clone.
QuadrupenFit, ridge()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.