Skip to contents

Class of object returned by the fitting function elastic_net(). Inherits fields and methods of QuadrupenFit

Super class

QuadrupenFit -> SparseFit

Active bindings

lambda1

vector of tuning parameters for the l1 penalty

lambda2

vector of tuning parameters for the l2 penalty

penalty

character describing the regularizer/penalty

type

string the type of group-wise regularization applied

unbiasing_tuning

unbiasing coefficient of the MCP or SCAD penalties

Methods

Inherited methods


SparseFit$new()

Initialize a SparseFit model

Usage

SparseFit$new(data, intercept, type, regParam)

Arguments

data

a DataModel object

intercept

a logical; should an intercept be included in the mode?

type

string the type of group-wise regularization applied

regParam

a list with two elements, a vector and a scalar, for the regularization


SparseFit$clone()

The objects of this class are cloneable with this method.

Usage

SparseFit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.