Class of object returned by the fitting function elastic_net(). Inherits fields
and methods of QuadrupenFit
Super class
QuadrupenFit -> SparseFit
Active bindings
lambda1vector of tuning parameters for the l1 penalty
lambda2vector of tuning parameters for the l2 penalty
penaltycharacter describing the regularizer/penalty
typestring the type of group-wise regularization applied
unbiasing_tuningunbiasing coefficient of the MCP or SCAD penalties
Methods
SparseFit$new()
Initialize a SparseFit model
Usage
SparseFit$new(data, intercept, type, regParam)Arguments
dataa
DataModelobjectintercepta logical; should an intercept be included in the mode?
typestring the type of group-wise regularization applied
regParama list with two elements, a vector and a scalar, for the regularization