Class of object returned by the fitting function group_sparse_lm(). Inherits fields
and methods of QuadrupenFit
Super class
QuadrupenFit -> SparseGroupFit
Active bindings
lambda1vector of tuning parameters for the l1 group penalty
lambda2vector of tuning parameters for the l2 penalty
alphamixing parameter of the sparse group-penalty
penaltycharacter describing the regularizer/penalty
groupvector of integers indicating group belonging
typestring the type of group-wise regularization applied
mixture_tuningmixture coefficient of the sparse group penalty
is_group_sparseboolean indicating if sparse group or group penalty is applied
Methods
SparseGroupFit$new()
Initialize a SparseGroupFit model
Usage
SparseGroupFit$new(data, intercept, group, type, regParam)Arguments
dataa
DataModelobjectintercepta logical; should an intercept be included in the mode?
groupvector of integers indicating group belonging.
typestring indicating whether the \(\ell_1/\ell_2\) or the \(\ell_1/\ell_\infty\) group-Lasso must be fitted.
regParama list with two elements, a vector and a scalar, for the regularization