| SparseGroupFit | R Documentation |
Class of object returned by the fitting function group_sparse_lm(). Inherits fields
and methods of QuadrupenFit
QuadrupenFit -> SparseGroupFit
lambda1vector of tuning parameters for the l1 group penalty
lambda2vector of tuning parameters for the l2 penalty
alphamixing parameter of the sparse group-penalty
penaltycharacter describing the regularizer/penalty
groupvector of integers indicating group belonging
typestring the type of group-wise regularization applied
mixture_tuningmixture coefficient of the sparse group penalty
is_group_sparseboolean indicating if sparse group or group penalty is applied
SparseGroupFit$new()Initialize a SparseGroupFit model
SparseGroupFit$new(data, intercept, group, type, regParam)
dataa DataModel object
intercepta logical; should an intercept be included in the mode?
groupvector of integers indicating group belonging.
typestring indicating whether the \ell_1/\ell_2 or the
\ell_1/\ell_\infty group-Lasso must be fitted.
regParama list with two elements, a vector and a scalar, for the regularization
SparseGroupFit$clone()The objects of this class are cloneable with this method.
SparseGroupFit$clone(deep = FALSE)
deepWhether to make a deep clone.
QuadrupenFit, group_sparse_lm()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.