Auxiliary functions to check the given class of an object
Source:R/quadrupen-S3Methods.R
isQuadrupenFit.RdAuxiliary functions to check the given class of an object
R/quadrupen-S3Methods.R
isQuadrupenFit.RdAuxiliary functions to check the given class of an object