Predict response for new sample based on the current model
Usage
# S3 method for class 'QuadrupenFit'
predict(object, newx = NULL, selection = NULL, ...)Predict response for new sample based on the current model
# S3 method for class 'QuadrupenFit'
predict(object, newx = NULL, selection = NULL, ...)