View source: R/quadrupen-S3Methods.R
| predict.QuadrupenFit | R Documentation |
Predict response for new sample based on the current model
## S3 method for class 'QuadrupenFit'
predict(object, newx = NULL, selection = NULL, ...)
object |
an R object to evaluate |
newx |
matrix of new values for the regressor with which to predict. If omitted, the fitted values are used. |
selection |
either a character (model selection criteria) of a scalar (lambda value) |
... |
not used, only here for S3 compatibility |
a vector of predicted value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.